@@ -35,5 +35,5 @@ class RandomPolicy(Policy):
 
         """
         # choose operator randomly
-        index = random.randint(0, len(self._operators) - 1)
-        return self._operators[index]
+        index = random.randint(0, len(self.operators) - 1)
+        return self.operators[index]
